@@ -1,28 +1,81 @@
 use crate::api::AuthInfo;
 use crate::api::{token::responses::LookupTokenResponse, EndpointMiddleware};
 use crate::error::ClientError;
-use crate::login::core::{LoginMethod, MultiLoginCallback, MultiLoginMethod};
-use rustify::clients::reqwest::Client;
+use async_trait::async_trait;
+use rustify::clients::reqwest::Client as HTTPClient;
 use std::{env, fs};
 use url::Url;
 
 /// Valid URL schemes that can be used for a Vault server address
 const VALID_SCHEMES: [&str; 2] = ["http", "https"];
 
+/// The client interface capabale of interacting with API functions
+#[async_trait]
+pub trait Client: Send + Sync + Sized {
+    /// Returns the underlying HTTP client being used for API calls
+    fn http(&self) -> &HTTPClient;
+
+    /// Returns the middleware to be used when executing API calls
+    fn middle(&self) -> &EndpointMiddleware;
+
+    /// Returns the settings used to configure this client
+    fn settings(&self) -> &VaultClientSettings;
+
+    /// Sets the underlying token for this client
+    fn set_token(&mut self, token: &str);
+
+    /// Looks up the current token being used by this client
+    async fn lookup(&self) -> Result<LookupTokenResponse, ClientError> {
+        crate::token::lookup_self(self).await
+    }
+
+    /// Renews the current token being used by this client
+    async fn renew(&self, increment: Option<&str>) -> Result<AuthInfo, ClientError> {
+        crate::token::renew_self(self, increment).await
+    }
+
+    /// Revokes the current token being used by this client
+    async fn revoke(&self) -> Result<(), ClientError> {
+        crate::token::revoke_self(self).await
+    }
+
+    /// Returns the status of the configured Vault server
+    async fn status(&self) -> Result<crate::sys::ServerStatus, ClientError> {
+        crate::sys::status(self).await
+    }
+}
+
 /// A client which can be used to execute calls against a Vault server.
 ///
 /// A vault client is configured using [VaultClientSettings] and will
-/// automatically configure a backing instance of a [ReqwestClient] which is
-/// used for executing [Endpoints][rustify::endpoint::Endpoint]. All requests
-/// made will automatically be configured according to how this client is setup
-/// (i.e adding the Vault token to requests). All calls using this client are
-/// blocking.
+/// automatically configure a backing instance of a [HTTPClient] which is
+/// used for executing [Endpoints][rustify::endpoint::Endpoint].
 pub struct VaultClient {
-    pub http: Client,
+    pub http: HTTPClient,
     pub middle: EndpointMiddleware,
     pub settings: VaultClientSettings,
 }
 
+#[async_trait]
+impl Client for VaultClient {
+    fn http(&self) -> &HTTPClient {
+        &self.http
+    }
+
+    fn middle(&self) -> &EndpointMiddleware {
+        &self.middle
+    }
+
+    fn settings(&self) -> &VaultClientSettings {
+        &self.settings
+    }
+
+    fn set_token(&mut self, token: &str) {
+        self.settings.token = token.to_string();
+        self.middle.token = token.to_string();
+    }
+}
+
 impl VaultClient {
     /// Creates a new [VaultClient] using the given [VaultClientSettings].
     pub fn new(settings: VaultClientSettings) -> Result<VaultClient, ClientError> {
@@ -58,91 +111,13 @@ impl VaultClient {
         let http_client = http_client
             .build()
             .map_err(|e| ClientError::RestClientBuildError { source: e })?;
-        let http = Client::new(settings.address.as_str(), http_client);
+        let http = HTTPClient::new(settings.address.as_str(), http_client);
         Ok(VaultClient {
             settings,
             middle,
             http,
         })
     }
-
-    /// Performs a login using the given method and sets the resulting token to
-    /// this client.
-    pub async fn login(
-        &mut self,
-        mount: &str,
-        method: &impl LoginMethod,
-    ) -> Result<(), ClientError> {
-        let info = method.login(self, mount).await?;
-        self.settings.token = info.client_token.clone();
-        self.middle.token = info.client_token;
-        Ok(())
-    }
-
-    /// Performs the first step of a multi-step login, returning the resulting
-    /// callback which must be passed back to the client to finish the login
-    /// flow.
-    pub async fn login_multi<M: MultiLoginMethod>(
-        &self,
-        mount: &str,
-        method: M,
-    ) -> Result<M::Callback, ClientError> {
-        method.login::<M::Callback>(self, mount).await
-    }
-
-    /// Performs the second step of a multi-step login and sets the resulting
-    /// token to this client.
-    pub async fn login_multi_callback(
-        &mut self,
-        mount: &str,
-        callback: impl MultiLoginCallback,
-    ) -> Result<(), ClientError> {
-        let info = callback.callback(self, mount).await?;
-        self.settings.token = info.client_token.clone();
-        self.middle.token = info.client_token;
-        Ok(())
-    }
-
-    /// Writes the token configured for this client to the default location.
-    pub fn token_to_file(&mut self) -> Result<(), ClientError> {
-        let home_dir = dirs::home_dir();
-        let token_file = match home_dir {
-            Some(d) => d.join(".vault-token"),
-            None => {
-                return Err(ClientError::FileNotFoundError {
-                    path: "$HOME".to_string(),
-                })
-            }
-        };
-
-        let token_file_string = token_file.to_string_lossy().to_string();
-        std::fs::write(token_file, self.settings.token.clone()).map_err(|e| {
-            ClientError::FileWriteError {
-                source: e,
-                path: token_file_string,
-            }
-        })
-    }
-
-    /// Looks up the current token being used by this client
-    pub async fn lookup(&self) -> Result<LookupTokenResponse, ClientError> {
-        crate::token::lookup_self(self).await
-    }
-
-    /// Renews the current token being used by this client
-    pub async fn renew(&self, increment: Option<&str>) -> Result<AuthInfo, ClientError> {
-        crate::token::renew_self(self, increment).await
-    }
-
-    /// Revokes the current token being used by this client
-    pub async fn revoke(&self) -> Result<(), ClientError> {
-        crate::token::revoke_self(self).await
-    }
-
-    /// Returns the status of the configured Vault server
-    pub async fn status(&self) -> crate::sys::ServerStatus {
-        crate::sys::status(self).await
-    }
 }
 
 /// Contains settings for configuring a [VaultClient].
@@ -205,31 +180,6 @@ impl VaultClientSettingsBuilder {
         paths
     }
 
-    /// Reads a token from the default location and returns it
-    pub fn token_from_file() -> Result<String, ClientError> {
-        let home_dir = dirs::home_dir();
-        let token_file = match home_dir {
-            Some(d) => d.join(".vault-token"),
-            None => {
-                return Err(ClientError::FileNotFoundError {
-                    path: "$HOME".to_string(),
-                })
-            }
-        };
-
-        let token_file_string = token_file.to_string_lossy().to_string();
-        if !token_file.exists() {
-            return Err(ClientError::FileNotFoundError {
-                path: token_file_string,
-            });
-        }
-
-        fs::read_to_string(token_file).map_err(|e| ClientError::FileReadError {
-            source: e,
-            path: token_file_string.clone(),
-        })
-    }
-
     fn validate(&self) -> Result<(), String> {
         // Verify URL is valid
         let address = self.address.as_ref().unwrap().as_str();
